Package 'mrenergy'

Title: Preprocessing functions for REMIND and other energy models using landuse data
Description: Preprocessing functions for REMIND and other energy models (buildings, transport, industry) using landuse data.
Authors: Falk Benke [aut, cre]
Maintainer: Falk Benke <[email protected]>
License: LGPL-3
Version: 0.1.4
Built: 2026-06-27 10:44:50 UTC
Source: https://github.com/pik-piam/mrenergy

Help Index


mrenergy: Preprocessing functions for REMIND and other energy models using landuse data

Description

Preprocessing functions for REMIND and other energy models (buildings, transport, industry) using landuse data.

Author(s)

Maintainer: Falk Benke [email protected]

Authors:

See Also

Useful links:


calcEmissions

Description

calcEmissions

Usage

calcEmissions(datasource = "CEDS16")

Arguments

datasource

"CEDS2REMIND", "CEDS2025", "EDGAR6", "EDGARghg", "CDIAC", "ClimateTrace"

Value

magpie object with historical emissions

Author(s)

Steve Smith, Pascal Weigmann


Calculates FE historical from IEA energy balances

Description

Calculates FE historical from IEA energy balances

Usage

calcFE(ieaVersion = "default")

Arguments

ieaVersion

Release version of IEA data, either 'default' (vetted and used in REMIND) or 'latest'.

Author(s)

Lavinia Baumstark, Aman Malik


Calc Input Output

Description

Computes IEA-based model data for different "subtypes" by use of raw IEA "Energy Balances" data and a mapping that corresponds to the structure of "products" and "flows" of IEA.

Usage

calcIO(
  subtype = c("input", "output", "trade"),
  ieaVersion = "default",
  corrected = FALSE
)

Arguments

subtype

Data subtype. See default argument for possible values.

ieaVersion

Release version of IEA data, either 'default' (vetted and used in REMIND) or 'latest'.

corrected

boolean indicating whether corrections should be applied to the data after mapping

Details

Mapping structure example: IEA product ANTCOAL used for IEA flow TPATFUEL, contributes via REMIND technology coaltr for generating sesofos from pecoal (REMIND names)

Value

IEA data as MAgPIE object aggregated to country level

Author(s)

Anastasis Giannousakis

Examples

## Not run: 
a <- calcOutput("IO", subtype = "output")

## End(Not run)

Calculate LDV Shares using EDGE-Transport

Description

Calculate LDV Shares using EDGE-Transport

Usage

calcLDVShares()

Author(s)

Johanna Hoppe, Falk Benke


Convert ClimateTrace data

Description

Convert ClimateTrace data

Usage

convertClimateTrace(x)

Arguments

x

A magpie object returned from readClimateTrace().

Value

A magpie object.

Author(s)

Pascal Weigmann


Convert IEA ETP projections

Description

Convert IEA ETP projections

Usage

convertIEA_ETP(x, subtype)

Arguments

x

IEA ETP projection magpie object derived from readIEA_ETP function

subtype

data subtype. Either "industry", "buildings", "summary", or "transport"

Author(s)

Falk Benke, Robin Hasse


Read Climate Trace

Description

Read in Climate Trace csv files as magclass object for CO2, CH4 and N2O emissions by subsector and country.

Usage

readClimateTrace()

Value

magpie object of the ClimateTrace data with historical emissions

Author(s)

Pascal Weigmann

Examples

## Not run: 
a <- readSource(type = "ClimateTrace")

## End(Not run)

Read IEA ETP projections

Description

Read IEA ETP projections

Usage

readIEA_ETP(subtype)

Arguments

subtype

data subtype. Either "industry", "buildings", "summary", or "transport"

Author(s)

Falk Benke