| Title: | Preprocessing functions for REMIND and other energy models using landuse data |
|---|---|
| Description: | Preprocessing functions for REMIND and other energy models (buildings, transport, industry) using landuse data. |
| Authors: | Falk Benke [aut, cre] |
| Maintainer: | Falk Benke <[email protected]> |
| License: | LGPL-3 |
| Version: | 0.1.4 |
| Built: | 2026-06-27 10:44:50 UTC |
| Source: | https://github.com/pik-piam/mrenergy |
Preprocessing functions for REMIND and other energy models (buildings, transport, industry) using landuse data.
Maintainer: Falk Benke [email protected]
Authors:
Falk Benke [email protected]
Useful links:
calcEmissions
calcEmissions(datasource = "CEDS16")calcEmissions(datasource = "CEDS16")
datasource |
"CEDS2REMIND", "CEDS2025", "EDGAR6", "EDGARghg", "CDIAC", "ClimateTrace" |
magpie object with historical emissions
Steve Smith, Pascal Weigmann
Calculates FE historical from IEA energy balances
calcFE(ieaVersion = "default")calcFE(ieaVersion = "default")
ieaVersion |
Release version of IEA data, either 'default' (vetted and used in REMIND) or 'latest'. |
Lavinia Baumstark, Aman Malik
Computes IEA-based model data for different "subtypes" by use of raw IEA "Energy Balances" data and a mapping that corresponds to the structure of "products" and "flows" of IEA.
calcIO( subtype = c("input", "output", "trade"), ieaVersion = "default", corrected = FALSE )calcIO( subtype = c("input", "output", "trade"), ieaVersion = "default", corrected = FALSE )
subtype |
Data subtype. See default argument for possible values. |
ieaVersion |
Release version of IEA data, either 'default' (vetted and used in REMIND) or 'latest'. |
corrected |
boolean indicating whether corrections should be applied to the data after mapping |
Mapping structure example: IEA product ANTCOAL used for IEA flow TPATFUEL, contributes via REMIND technology coaltr for generating sesofos from pecoal (REMIND names)
IEA data as MAgPIE object aggregated to country level
Anastasis Giannousakis
## Not run: a <- calcOutput("IO", subtype = "output") ## End(Not run)## Not run: a <- calcOutput("IO", subtype = "output") ## End(Not run)
Convert ClimateTrace data
convertClimateTrace(x)convertClimateTrace(x)
x |
A |
A magpie object.
Pascal Weigmann
Convert IEA ETP projections
convertIEA_ETP(x, subtype)convertIEA_ETP(x, subtype)
x |
IEA ETP projection magpie object derived from readIEA_ETP function |
subtype |
data subtype. Either "industry", "buildings", "summary", or "transport" |
Falk Benke, Robin Hasse
Read in Climate Trace csv files as magclass object for CO2, CH4 and N2O emissions by subsector and country.
readClimateTrace()readClimateTrace()
magpie object of the ClimateTrace data with historical emissions
Pascal Weigmann
## Not run: a <- readSource(type = "ClimateTrace") ## End(Not run)## Not run: a <- readSource(type = "ClimateTrace") ## End(Not run)
Read IEA ETP projections
readIEA_ETP(subtype)readIEA_ETP(subtype)
subtype |
data subtype. Either "industry", "buildings", "summary", or "transport" |
Falk Benke